@@ -2,7 +2,6 @@ module Fog
   module Compute
     class Bluebox
       class Real
-
         # Create a new block
         #
         # ==== Parameters
@@ -19,8 +18,7 @@ module Fog
         # * response<~Excon::Response>:
         #   * body<~Hash>:
         def create_block(product_id, template_id, location_id, options = {})
-
-          unless options.has_key?('password') || options.has_key?('ssh_public_key')
+          unless options.key?('password') || options.key?('ssh_public_key')
             raise ArgumentError, 'Either password or public_key must be supplied'
           end
 
@@ -40,7 +38,6 @@ module Fog
             :body     => options.map {|k,v| "#{CGI.escape(k)}=#{CGI.escape(v)}"}.join('&')
           )
         end
-
       end
     end
   end
