@@ -6,7 +6,7 @@ module Fog
       class LibVolume < Fog::Model
         identity :uuid
 
-        attribute :mounted_on, :type => :related
+        attribute :mounted_on
         attribute :licenses
         attribute :meta
         attribute :owner
@@ -31,8 +31,6 @@ module Fog
         attribute :os, :type => :string
         attribute :resource_uri, :type => :string
 
-
-
         def reload
           requires :identity
           collection.get(identity)
