@@ -4,7 +4,6 @@ require 'uri'
 
 module Fog
   module Cloudstack
-
     extend Fog::Provider
 
     service(:compute, 'Compute')
@@ -14,11 +13,13 @@ module Fog
     def self.escape(string)
       string = CGI::escape(string)
       string = string.gsub("+","%20")
+      # Escaped asterisk will cause malformed request
+      string = string.gsub("%2A","*")
       string
     end
 
     def self.signed_params(key,params)
-      query = params.map{|k,v| [k.to_s, v]}.sort.collect{|c| "#{c[0]}=#{escape(c[1].to_s)}"}.join('&').downcase
+      query = params.map{|k,v| [k.to_s, v]}.sort.map{|c| "#{c[0]}=#{escape(c[1].to_s)}"}.join('&').downcase
 
       signed_string = Base64.encode64(OpenSSL::HMAC.digest(@@digest,key,query)).strip
 
@@ -38,4 +39,3 @@ module Fog
     end
   end
 end
-
