@@ -1,21 +1,23 @@
 module Fog
   module Compute
     class Cloudstack
+
       class Real
-
-        # Creates an account.
+        # Deletes security group
         #
-        # {CloudStack API Reference}[http://download.cloud.com/releases/2.2.0/api_2.2.4/global_admin/deleteSecurityGroup.html]
-        def delete_security_group(options={})
-          options.merge!(
-            'command' => 'deleteSecurityGroup'
-          )
-
+        # {CloudStack API Reference}[http://cloudstack.apache.org/docs/api/apidocs-4.4/root_admin/deleteSecurityGroup.html]
+        def delete_security_group(*args)
+          options = {}
+          if args[0].is_a? Hash
+            options = args[0]
+            options.merge!('command' => 'deleteSecurityGroup') 
+          else
+            options.merge!('command' => 'deleteSecurityGroup')
+          end
           request(options)
         end
-
-      end # Real
-
+      end
+ 
       class Mock
         def delete_security_group(options={})
           security_group_id = options['id']
@@ -30,8 +32,8 @@ module Fog
             raise Fog::Compute::Cloudstack::BadRequest.new('No security_group found')
           end
         end
-      end
-
+      end 
     end
   end
 end
+
