@@ -3,7 +3,6 @@ require 'fog/core/model'
 module Fog
   module DNS
     class DNSMadeEasy
-
       class Record < Fog::Model
         extend Fog::Deprecation
         deprecate :ip, :value
@@ -29,7 +28,7 @@ module Fog
         end
 
         def destroy
-          service.delete_record(zone.domain, identity)
+          service.delete_record(zone.id, identity)
           true
         end
 
@@ -72,9 +71,7 @@ module Fog
         def zone=(new_zone)
           @zone = new_zone
         end
-
       end
-
     end
   end
 end
