@@ -3,9 +3,8 @@ module Fog
     class Fogdocker
       class Real
         def image_get(id)
-          downcase_hash_keys Docker::Image.get(id).json
+          downcase_hash_keys Docker::Image.get(id, {}, @connection).json
         end
-
       end
       class Mock
         def image_get(id)
@@ -17,4 +16,4 @@ module Fog
       end
     end
   end
-end
\ No newline at end of file
+end
