@@ -8,6 +8,8 @@ module Fog
         attribute :name
         attribute :bits
         attribute :image_size
+        attribute :created_at, types: 'time'
+        attribute :requires_pvops_kernel
       end
     end
   end
