@@ -56,8 +56,10 @@ module Fog
             "DISK" => 20,
             "CORES" => 1,
             "AVAIL" => {
-              "3"=>48, "2"=>207, "7"=>161, "6"=>143, "4"=>108, "8"=>60
-            }
+              "2" => 500, "3" => 500, "4" => 500, "6" => 500, "7" => 500,
+              "8" => 500, "9" => 500, "10" => 500
+            },
+            "HOURLY" => 0.03
           }
         end
       end
