@@ -2,7 +2,6 @@ module Fog
   module Vcloud
     class Compute
       class CatalogItems < Fog::Vcloud::Collection
-
         undef_method :create
 
         model Fog::Vcloud::Compute::CatalogItem
@@ -10,12 +9,16 @@ module Fog
         attribute :href, :aliases => :Href
 
         def all
-          data = connection.get_catalog(href).body[:CatalogItems][:CatalogItem]
-          load(data)
+          catalog_item_info = service.get_catalog_item(self.href)
+          items = service.get_catalog_item(self.href).body[:CatalogItems]
+          if items.size > 0
+            data = items[:CatalogItem]
+            load(data)
+          end
         end
 
         def get(uri)
-          if data = connection.get_catalog_item(uri)
+          if data = service.get_catalog_item(uri)
             new(data.body)
           end
         rescue Fog::Errors::NotFound
@@ -23,9 +26,8 @@ module Fog
         end
 
         def organization_uri
-          @organization_uri ||= connection.default_organization_uri
+          @organization_uri ||= service.default_organization_uri
         end
-
       end
     end
   end
