@@ -2,10 +2,9 @@ module Fog
   module Vcloud
     class Compute
       class Real
-
         def configure_metadata(opts= {})
           valid_opts = [:key, :value, :href]
-          unless valid_opts.all? { |opt| opts.has_key?(opt) }
+          unless valid_opts.all? { |opt| opts.key?(opt) }
             raise ArgumentError.new("Required data missing: #{(valid_opts - opts.keys).map(&:inspect).join(", ")}")
           end
 
@@ -29,7 +28,6 @@ EOF
             :parse    => true
           )
         end
-
       end
     end
   end
