@@ -2,10 +2,9 @@ module Fog
   module Vcloud
     class Compute
       class Real
-
         def validate_network_data(network_data, configure=false)
           valid_opts = [:id, :href, :name, :address, :broadcast, :gateway]
-          unless valid_opts.all? { |opt| network_data.has_key?(opt) }
+          unless valid_opts.all? { |opt| network_data.key?(opt) }
             raise ArgumentError.new("Required data missing: #{(valid_opts - network_data.keys).map(&:inspect).join(", ")}")
           end
         end
@@ -36,7 +35,6 @@ module Fog
             builder.GatewayAddress(network_data[:gateway])
           }
         end
-
       end
     end
   end
