@@ -14,11 +14,13 @@ module Fog
         attribute :description
         attribute :href
         attribute :status
+        attribute :deployed
         attribute :operating_system
         attribute :ip_address
         attribute :cpu, :type => :integer
         attribute :memory, :type => :integer
         attribute :hard_disks, :aliases => :disks
+        attribute :network_adapters
 
         def reload
           # when collection.vapp is nil, it means it's fatherless,
@@ -90,6 +92,17 @@ module Fog
           service.process_task(response.body)
         end
 
+        def undeploy
+          requires :id
+          begin
+            response = service.post_undeploy_vapp(id)
+          rescue Fog::Compute::VcloudDirector::BadRequest => ex
+            Fog::Logger.debug(ex.message)
+            return false
+          end
+          service.process_task(response.body)
+        end
+
         # Shut down the VM.
         def shutdown
           requires :id
