@@ -31,7 +31,6 @@ module Fog
 Statistic     | Value
 ------------- | --------:
 Collaborators | #{collaborators}
-Downloads     | #{downloads}
 Forks         | #{forks}
 Open Issues   | #{open_issues}
 Watchers      | #{watchers}
@@ -109,6 +108,7 @@ Watchers      | #{watchers}
            'Benson Kalahar',
            'Brian Hartsock',
            'bryanl',
+           'Cherdancev Evgeni',
            'Chris Luo',
            'Chris Roberts',
            'Christopher Oliver',
@@ -118,6 +118,7 @@ Watchers      | #{watchers}
            'Darren Hague',
            'Decklin Foster',
            'Dylan Egan',
+           'effeminate-batman',
            'Erik Michaels-Ober',
            'Frederick Cheung',
            'geemus',
@@ -147,6 +148,7 @@ Watchers      | #{watchers}
            'Rodrigo Estebanez',
            'Rupak Ganguly',
            'Stepan G. Fedorov',
+           'swamp09',
            'TerryHowe',
            'Wesley Beary'
          ].include?(committer)
@@ -176,7 +178,7 @@ Watchers      | #{watchers}
       end
 
       def committer_match
-        @current_line.match /([\w\s]+)\s+\(\d+\)/
+        @current_line.match (/([-\w\s]+)\s+\(\d+\)/)
       end
 
       def last_release_sha
@@ -184,9 +186,9 @@ Watchers      | #{watchers}
       end
 
       def downloads
-        repsonse = Excon.get('https://rubygems.org/api/v1/gems/fog.json')
-        data = Fog::JSON.decode(repsonse.body)
-        data['downloads']
+        response = Excon.get('https://rubygems.org/api/v1/downloads/fog.json')
+        data = Fog::JSON.decode(response.body)
+        data['total_downloads']
       end
 
       def collaborators
