@@ -2,23 +2,23 @@ Shindo.tests('Fog::Compute[:cloudsigma] | server requests', ['cloudsigma']) do
 
   @server_format = {
       'uuid' => String,
-      'status' => String,
-      'vnc_password' => String,
-      'name' => String,
+      'cpu' => Integer,
       'cpus_instead_of_cores' => Fog::Boolean,
-      'tags' => Array,
-      'mem' => Integer,
+      'drives' => Array,
       'enable_numa' => Fog::Boolean,
-      'smp' => Integer,
       'hv_relaxed'  => Fog::Boolean,
       'hv_tsc' => Fog::Boolean,
+      'mem' => Integer,
       'meta' => Fog::Nullable::Hash,
+      'name' => String,
+      'nics' => Array,
       'owner' => Fog::Nullable::Hash,
-      'runtime' => Fog::Nullable::Hash,
-      'cpu' => Integer,
       'resource_uri' => Fog::Nullable::String,
-      'drives' => Array,
-      'nics' => Array
+      'runtime' => Fog::Nullable::Hash,
+      'smp' => Integer,
+      'status' => String,
+      'tags' => Array,
+      'vnc_password' => String
   }
 
   @server_create_args = {:name => 'fogtest', :cpu => 2000, :mem => 512*1024**2, :vnc_password => 'myrandompass'}
