@@ -67,32 +67,10 @@ def compute_providers
       },
       :mocked => false
     },
-    :hp       => {
-      :server_attributes => {
-        :flavor_id => 100,
-        :image_id  => 1242,
-        :name      => "fog_#{Time.now.to_i}"
-      },
-      :mocked => true
-    },
     :ibm => {
       :server_attributes => {},
       :mocked => true
     },
-    :joyent => {
-      :mocked => false
-    },
-    :hp       => {
-      :server_attributes => {
-        :flavor_id => 100,
-        :image_id => 1242,
-        :name     => "fog_#{Time.now.to_i}"
-      },
-      :mocked => true
-    },
-    :ninefold   => {
-      :mocked => false
-    },
     :openstack => {
       :mocked => true,
       :server_attributes => {
@@ -109,9 +87,6 @@ def compute_providers
         :name     => "fog_#{Time.now.to_i}"
       },
       :mocked => true
-    },
-    :xenserver => {
-      :mocked => false
     }
   }
 end
