@@ -45,16 +45,10 @@ if Fog.mock?
     :os_account_meta_temp_url_key     => 'os_account_meta_temp_url_key',
     :ibm_username                     => 'ibm_username',
     :ibm_password                     => 'ibm_password',
-    :joyent_username                  => "joyentuser",
-    :joyent_password                  => "joyentpass",
     :linode_api_key                   => 'linode_api_key',
     :local_root                       => '~/.fog',
     :bare_metal_cloud_password        => 'bare_metal_cloud_password',
     :bare_metal_cloud_username        => 'bare_metal_cloud_username',
-    :ninefold_compute_key             => 'ninefold_compute_key',
-    :ninefold_compute_secret          => 'ninefold_compute_secret',
-    :ninefold_storage_secret          => 'ninefold_storage_secret',
-    :ninefold_storage_token           => 'ninefold_storage_token',
 #    :public_key_path                  => '~/.ssh/id_rsa.pub',
 #    :private_key_path                 => '~/.ssh/id_rsa',
     :opennebula_endpoint              => 'http://opennebula:2633/RPC2',
@@ -64,9 +58,6 @@ if Fog.mock?
     :openstack_username               => 'openstack_username',
     :openstack_tenant                 => 'openstack_tenant',
     :openstack_auth_url               => 'http://openstack:35357/v2.0/tokens',
-    :ovirt_url                        => 'http://ovirt:8080/api',
-    :ovirt_username                   => 'admin@internal',
-    :ovirt_password                   => '123123',
     :profitbricks_username            => 'profitbricks_username',
     :profitbricks_password            => 'profitbricks_password',
     :rackspace_api_key                => 'rackspace_api_key',
