@@ -3,7 +3,8 @@ Shindo.tests('Fog::Compute[:linode] | datacenter requests', ['linode']) do
   @datacenters_format = Linode::Compute::Formats::BASIC.merge({
     'DATA' => [{
       'DATACENTERID'  => Integer,
-      'LOCATION'      => String
+      'LOCATION'      => String,
+      'ABBR'          => String
     }]
   })
 
