@@ -3,12 +3,14 @@ Shindo.tests('Fog::Compute[:linode] | linodeplans requests', ['linode']) do
   @linodeplans_format = Linode::Compute::Formats::BASIC.merge({
     'DATA' => [{
       'AVAIL' => {
-         '2' => Integer,
-         '3' => Integer,
-         '4' => Integer,
-         '6' => Integer,
-         '7' => Integer,
-         '8' => Integer
+         '2'  => Integer,
+         '3'  => Integer,
+         '4'  => Integer,
+         '6'  => Integer,
+         '7'  => Integer,
+         '8'  => Integer,
+         '9'  => Integer,
+         '10' => Integer
       },
       'DISK'    => Integer,
       'PLANID'  => Integer,
@@ -16,7 +18,8 @@ Shindo.tests('Fog::Compute[:linode] | linodeplans requests', ['linode']) do
       'RAM'     => Integer,
       'LABEL'   => String,
       'XFER'    => Integer,
-      'CORES'   => Integer
+      'CORES'   => Integer,
+      'HOURLY'  => Float
     }]
   })
 
