@@ -107,6 +107,18 @@ Shindo.tests('Fog::DNS[:rage4] | DNS requests', ['rage4', 'dns']) do
 
     end
 
+    test("bulk_update_records") do
+      pending if Fog.mocking?
+
+      data = { :id => @record_id, :priority => 1 }
+      response = Fog::DNS[:rage4].bulk_update_records(@zone_id, { :body => data.to_json } )
+
+      returns(200) { response.status }
+      returns(true) {response.body['status']}
+      returns(@domain_id) {response.body['id']}
+      returns("") {response.body['error'] }
+    end
+
     test("show_current_usage") do
       pending if Fog.mocking?
 
