@@ -1,6 +1,6 @@
 for provider, config in storage_providers
 
-  Shindo.tests("Storage[:#{provider}] | file", [provider]) do
+  Shindo.tests("Storage[:#{provider}] | file", [provider.to_s]) do
 
     if !Fog.mocking? || config[:mocked]
 
@@ -21,7 +21,7 @@ for provider, config in storage_providers
         responds_to(:public_url)
 
         tests("#public=(true)").succeeds do
-          pending if Fog.mocking? && !config[:mocked]
+          pending if Fog.mocking? && !config[:mocked] || !Fog::Storage[provider].respond_to?(:public=)
           @instance.public=(true)
         end
 
